==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1VolumeMountFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1VolumeMountFluentImpl<A extends V1VolumeMountFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1VolumeMountFluent<A>{

    private String mountPath;
    private String mountPropagation;
    private String name;
    private Boolean readOnly;
    private String subPath;

    public V1VolumeMountFluentImpl(){
    }
    public V1VolumeMountFluentImpl(V1VolumeMount instance){
            this.withMountPath(instance.getMountPath());

            this.withMountPropagation(instance.getMountPropagation());

            this.withName(instance.getName());

            this.withReadOnly(instance.isReadOnly());

            this.withSubPath(instance.getSubPath());

    }

    public String getMountPath(){
            return this.mountPath;
    }

    public A withMountPath(String mountPath){
            this.mountPath=mountPath; return (A) this;
    }

    public Boolean hasMountPath(){
            return this.mountPath != null;
    }

    public String getMountPropagation(){
            return this.mountPropagation;
    }

    public A withMountPropagation(String mountPropagation){
            this.mountPropagation=mountPropagation; return (A) this;
    }

    public Boolean hasMountPropagation(){
            return this.mountPropagation != null;
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public Boolean isReadOnly(){
            return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly){
            this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly(){
            return this.readOnly != null;
    }

    public A withNewReadOnly(boolean arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(String arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public String getSubPath(){
            return this.subPath;
    }

    public A withSubPath(String subPath){
            this.subPath=subPath; return (A) this;
    }

    public Boolean hasSubPath(){
            return this.subPath != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1VolumeMountFluentImpl that = (V1VolumeMountFluentImpl) o;
            if (mountPath != null ? !mountPath.equals(that.mountPath) :that.mountPath != null) return false;
            if (mountPropagation != null ? !mountPropagation.equals(that.mountPropagation) :that.mountPropagation != null) return false;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
            if (subPath != null ? !subPath.equals(that.subPath) :that.subPath != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1VolumeMountFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1VolumeMountFluentImpl<A extends V1VolumeMountFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1VolumeMountFluent<A>{

    private String mountPath;
    private String mountPropagation;
    private String name;
    private Boolean readOnly;
    private String subPath;

    public V1VolumeMountFluentImpl(){
    }
    public V1VolumeMountFluentImpl(V1VolumeMount instance){
            this.withMountPath(instance.getMountPath());

            this.withMountPropagation(instance.getMountPropagation());

            this.withName(instance.getName());

            this.withReadOnly(instance.isReadOnly());

            this.withSubPath(instance.getSubPath());

    }

    public String getMountPath(){
            return this.mountPath;
    }

    public A withMountPath(String mountPath){
            this.mountPath=mountPath; return (A) this;
    }

    public Boolean hasMountPath(){
            return this.mountPath != null;
    }

    public A withNewMountPath(String arg1){
            return (A)withMountPath(new String(arg1));
    }

    public A withNewMountPath(StringBuilder arg1){
            return (A)withMountPath(new String(arg1));
    }

    public A withNewMountPath(StringBuffer arg1){
            return (A)withMountPath(new String(arg1));
    }

    public String getMountPropagation(){
            return this.mountPropagation;
    }

    public A withMountPropagation(String mountPropagation){
            this.mountPropagation=mountPropagation; return (A) this;
    }

    public Boolean hasMountPropagation(){
            return this.mountPropagation != null;
    }

    public A withNewMountPropagation(String arg1){
            return (A)withMountPropagation(new String(arg1));
    }

    public A withNewMountPropagation(StringBuilder arg1){
            return (A)withMountPropagation(new String(arg1));
    }

    public A withNewMountPropagation(StringBuffer arg1){
            return (A)withMountPropagation(new String(arg1));
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public A withNewName(String arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1){
            return (A)withName(new String(arg1));
    }

    public Boolean isReadOnly(){
            return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly){
            this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly(){
            return this.readOnly != null;
    }

    public A withNewReadOnly(String arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(boolean arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public String getSubPath(){
            return this.subPath;
    }

    public A withSubPath(String subPath){
            this.subPath=subPath; return (A) this;
    }

    public Boolean hasSubPath(){
            return this.subPath != null;
    }

    public A withNewSubPath(String arg1){
            return (A)withSubPath(new String(arg1));
    }

    public A withNewSubPath(StringBuilder arg1){
            return (A)withSubPath(new String(arg1));
    }

    public A withNewSubPath(StringBuffer arg1){
            return (A)withSubPath(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1VolumeMountFluentImpl that = (V1VolumeMountFluentImpl) o;
            if (mountPath != null ? !mountPath.equals(that.mountPath) :that.mountPath != null) return false;
            if (mountPropagation != null ? !mountPropagation.equals(that.mountPropagation) :that.mountPropagation != null) return false;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
            if (subPath != null ? !subPath.equals(that.subPath) :that.subPath != null) return false;
            return true;
    }




}
